==> nextcloud-app-tasks-0.9.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/af.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Take",
    "Started yesterday" : "Gister begin",
    "Starts today" : "Begin vandag",
    "Starts tomorrow" : "Begin môre",
    "Started on" : "Het begin op",
    "Starts on" : "Begin op",
    "[Remind me yesterday at ]HH:mm" : "[Herinner my gister om ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Herinner my vandag om ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Herinner my môre om ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Herinner my op ]DD MMM YYYY,[ om ]HH:mm",
    "Yesterday" : "Gister",
    "Today" : "Vandag",
    "Tomorrow" : "Môre",
    "in %s" : "in %s",
    "%s ago" : "%s gelede",
    "seconds" : "sekondes",
    "a minute" : "’n minuut",
    "%d minutes" : "%d minute",
    "an hour" : "’n uur",
    "%d hours" : "%d uur",
    "a day" : "’n dag",
    "%d days" : "%d dae",
    "a month" : "’n maand",
    "%d months" : "%d maande",
    "a year" : "’n jaar",
    "%d years" : "%d jaar",
    "week" : "week",
    "weeks" : "weke",
    "day" : "dag",
    "days" : "dae",
    "hour" : "uur",
    "hours" : "uur",
    "minute" : "minuut",
    "minutes" : "minute",
    "second" : "sekonde",
    "before beginning" : "voor aanvangs",
    "after beginning" : "na aanvangs",
    "before end" : "voor einde",
    "after end" : "na einde",
    "Comment" : "Kommentaar",
    "Add a comment" : "Voeg kommentaar toe",
    "The name \"%s\" is already used." : "Die naam “%s” bestaan reeds.",
    "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
    "Hidden" : "Versteek",
    "Visible" : "Sigbaar",
    "Automatic" : "Outomaties",
    "Sunday" : "Sondag",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "Add an important item in \"%s\"..." : "'n Belangrike item in \"%s\"...",
    "Add an item in \"%s\"..." : "Voeg 'n item by in \"%s\"...",
    "Add a current item in \"%s\"..." : "Voeg 'n huidige item by in \"%s\"...",
    "Add a subtask to \"%s\"..." : "Voeg 'n subtaak by, by \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Voltooide taak","%n Voltooide take"],
    "Hours" : "Uur",
    "Minutes" : "Minute",
    "Set due date" : "Stel sperdatum",
    "%s %% completed" : "%s %% voltooi",
    "priority %s: " : "prioriteit %s:",
    "high" : "hoog",
    "medium" : "medium",
    "low" : "laag",
    "no priority assigned" : "geen prioriteit toegeken",
    "Remind me" : "Herinner my",
    "at the end" : "aan die einde",
    "at the beginning" : "aan die begin",
    "Set start date" : "Stel begindatum",
    "{calendar} shared by {owner}" : "{calendar} gedeel deur {owner}",
    "Unnamed" : "Naamloos",
    "Important" : "Belangrik",
    "Week" : "Week",
    "All" : "Alle",
    "Current" : "Huidige",
    "Completed" : "Voltooid",
    "Delete" : "Skrap",
    "Cancel" : "Kanselleer",
    "Edit" : "Wysig",
    "Link" : "Skakel",
    "Download" : "Laai Af",
    "Save" : "Stoor",
    "Add List..." : "Voeg lys by...",
    "New List" : "Nuwe lys",
    "Settings" : "Instellings",
    "Start of week" : "Begin van week",
    "Visibility of Smart Collections" : "Sigbaarheid van Slimversamelings",
    "Change sort order" : "Verander sorteer volgorde",
    "Default" : "Verstek",
    "Due date" : "Sperdatum",
    "Start date" : "Begindatum",
    "Priority" : "Prioriteit",
    "Alphabetically" : "Alfabeties",
    "Manually" : "Handmatig",
    "Load remaining completed tasks." : "Laai oorblywende voltooide take.",
    "Task is completed" : "Taak is voltooid",
    "All day" : "Heeldag",
    "(New category)" : "(Nuwe kategorie)",
    "Select categories..." : "Kies kategorieë…",
    "Loading the task..." : "Laai tans die taak...",
    "Task not found!" : "Taak nie gevind!",
    "add a subtask to" : "Voeg 'n subtaak by, by",
    "Toggle subtasks" : "Wissel subtake",
    "Toggle completed subtasks" : "Wissel voltooide subtake"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.12.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/af.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Belangrik",
    "Today" : "Vandag",
    "Week" : "Week",
    "All" : "Alle",
    "Current" : "Huidige",
    "Completed" : "Voltooid",
    "Tasks" : "Take",
    "Share with users or groups" : "Deel met gebruikers of groepe",
    "No users or groups" : "Geen gebruikers of groepe",
    "can edit" : "kan wysig",
    "New List" : "Nuwe lys",
    "Cancel" : "Kanselleer",
    "Save" : "Stoor",
    "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
    "Edit" : "Wysig",
    "Copied" : "Gekopieer",
    "Can not copy" : "Kan nie kopieer nie",
    "Download" : "Laai Af",
    "Delete" : "Skrap",
    "Unshare" : "Ontdeel",
    "Visibility of Smart Collections" : "Sigbaarheid van Slimversamelings",
    "Hidden" : "Versteek",
    "Visible" : "Sigbaar",
    "Automatic" : "Outomaties",
    "Change sort order" : "Verander sorteer volgorde",
    "Start date" : "Begindatum",
    "Due date" : "Sperdatum",
    "Last modified" : "Laas gewysig",
    "Priority" : "Prioriteit",
    "Manually" : "Handmatig",
    "Alphabetically" : "Alfabeties",
    "Task is completed" : "Taak is voltooid",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Voltooide taak","%n Voltooide take"],
    "Tomorrow" : "Môre",
    "Set start date" : "Stel begindatum",
    "Set due date" : "Stel sperdatum",
    "All day" : "Heeldag",
    "Task not found!" : "Taak nie gevind!",
    "An error occurred" : "'n Fout het voorgekom"
},
"nplurals=2; plural=(n != 1);");
